@@ -215,7 +215,7 @@ has been supplied as an argument but L</uri> has not.
 
 sub insert {
     my ( $self, @args ) = @_;
-    if ( $self->name && !$self->uri ) {
+    if ( $self->name && !defined $self->uri ) {
         $self->generate_uri;
     }
     $self->next::method(@args);
